
# q-expansion of newform 1344.4.p.b, downloaded from the LMFDB on 08 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 1344
weight = 4
poly_data = [22595395600887201, 2604526546410882, 150109311002562, -121918187031822, 45261122709708, -113574152394, 15140222838, -15937543350, 8375926786, -610, 307862, -331354, 178264, 58, 2, -2, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-27512779392820488215121118061020289502522689317470149928628756670976, -25684324012141546177510367237216621091828366947281962683702476387191, 20404186052116562202741462924572881687169243933056147081630462278345, -997802955330759136797967660228010101299233804265147287461089752550, 5030832095432654145167384840394766780891112135880782583106321224, -2562654252619389092879471537984959752571463875690677887775891753, 2866631751248081953429874871219555769052694124619628058669282191, -171500451015098622089501435784606343191700532657854714484075434, 55388401282768469315636042116060748653444205649068250682378, -52039487735663319305314714727996284752882531245213476274975, 59753252771284522024344801379946877177074084867352016610113, -3619381008348501827255964225465908593933559267039512551544, -830471019198726616618034608339929596881041789620024014, -339153926372896622386689372124047867595203882064062101, 335950885618247967279498373742793767396889561560873567, -20372040911331273768374528122272119834228940879382732], 414050931230026968103902334268239292369094182596223731647303743459292], [[-2142946519476913733745826775141705937801165163035176097087298709438655, -134673337110990079347148844501533723047247620642330001678746225531324, -85081337895283610755656711561335631919644943135591770124823103478842, 1552859528452234722839157336775674873645998333556550051376402744340, -939234679874936269758467226214078752763936976545191718137765694331, -90079347073487095603379633374269480608014029474964794267759764100, -23663893295557167353466497002938941922580635788048660671361588512, 368783175579778885523638920955102616657988979236587057507353967, -20484711581934944701656579475438198216321594738011938347609185, -2127951228482841388788449042567371912914359920967507587337218, -519748952238255970916886251822300922783080188295314619633878, 7874218290007240753351076323274609176295110127249363146722, -109485160578423845615051582672567681008502572899303419085, -12157453852830963523682967628489607995283621896891547748, -2941461018839361133996095913242342630467008325221597344, 45320418688999110770704458039657844020190624914409901], 103273966759270799352585617477205783940990427732393610386861542478214], [[-90442229018330749549897527548683852577526698755063716590646065215850624964927, -5763577435944795056333230259403353410544912922805317017884981122865588316052, -4555312600638504504536331814170604100122250840681586463213824342421980451305, 495974557546598480756571492191906058128690007228485296392312336122127340029, -46183430758685167936684965589132103003414597841983480202324457809414184637, -4193960898332230954622882545619754730771246377015567154553204832008204036, -1171742332692849470967392912694897616554117350810734903449426954558445945, 77372464794331925504431185726685147054526427106807749864028486669997866, -988722016575511696080654490563087876650550251431245440032909175148663, -99282002394329282451856008904251528444747177830052775545955261647176, -25647638852017709217880893864405289411780583943149520666034572861357, 1622040644281937533185719249902640667430004657657683359786159767947, -4887175782480483910405285585083411166747724546240621879953211369, -566400938622568118793901553410143932084040255787848961433276570, -146078833754566609284060431394554972839173577700412469410632437, 9103372943098038935370609340584385200787733345343877153834368], 4881737791712010405091663921897289898823934442006572568786270390267373051134], [[-2015004126895821052249415257666681579561845935809716283520216898560712, -31890869265789418431682797900059850002931149162468856506585450285514, 73536759395838409635279811305621323410149966042572215220501876471610, 4125210953930752209797081591371910229492465109526373047126067822306, -977124792439879233842172312108439164216055783485656572649127113080, -10837871123296399696483872187279835974372091316406835742501137476, 22788844668016948939887993110091583513375826991217149256473919242, 1697157964540573299487407984710377026336472788206794606036006981, -20842467787705566672623795364824696714107168266747692315965500, -218406356321611978916399171619748894773689836956773670382996, 502135347329718243117387795386546718574485872469334065208282, 38485276257698990279353144794992588174910657538112543466704, -102655234697670930366277293610818028484554041683476512044, -1598607436869501686815000153265493495818906000247159360, 2808076239389776449832892696021631615681707165743300810, 220230204401576361258214452745797285428350960465855351], 103273966759270799352585617477205783940990427732393610386861542478214], [[2015004126895821052249415257666681579561845935809716283520216898560712, 238438802784331017136854032854471417884912004627256077280308535241942, -73536759395838409635279811305621323410149966042572215220501876471610, -4125210953930752209797081591371910229492465109526373047126067822306, 977124792439879233842172312108439164216055783485656572649127113080, 10837871123296399696483872187279835974372091316406835742501137476, -22788844668016948939887993110091583513375826991217149256473919242, -1697157964540573299487407984710377026336472788206794606036006981, 20842467787705566672623795364824696714107168266747692315965500, 218406356321611978916399171619748894773689836956773670382996, -502135347329718243117387795386546718574485872469334065208282, -38485276257698990279353144794992588174910657538112543466704, 102655234697670930366277293610818028484554041683476512044, 1598607436869501686815000153265493495818906000247159360, -2808076239389776449832892696021631615681707165743300810, -220230204401576361258214452745797285428350960465855351], 103273966759270799352585617477205783940990427732393610386861542478214], [[-775610880242235059425060865598572830686396602956801058423016504676270162142793, -707389173973934104993224567999894500028079598342611245834884152768643080654395, -5105169837584643959128636524866045032070147846817861130797404973039137352828, -26057947251007289387208974761505715457690670961415496848434691583214426619743, 155723779107126364996382520285474007976105647772222803523015630575702959114, -140454710180007137237130865569004987120747766303309828844706935899355317394, -14285616712440633520977480559209700869861483726711511428632773267964710461, -5407851304577148631145372046960442935115233518470181297798309421221733014, 1675858371194556230481696384665346743794962266371653222079305911857073, -2630822658357093312374323529403556663210325174299279915336949198706571, -350712304448915925078037756268571563970142979559426865547238148958944, -115038887839561104742623831277596516029668867285108693628835090453653, -25916316475810500827135181484612500373548376790058957105918972554, -12314518214071923204347470349060537259443360271610928596378800292, -2042716625650269443877278803278445566173600785496108349213926807, -638967614307383683944410720193273711822693255849341088926315246], 278259054127584593090224843548145524232964263194374636420817412245240263914638], [[201984853779989756344596594417388295951892208491076375288003698, 301181151446221980050971520096822788435691492218274522733844587, 18615508925622104192286928662391437715268389415763779755904475, -12718284501737055946683966617303700724196188158293620432043841, 477779463226058036659718545075827740916878198140747249901016, 58083491311030260659368092652526214383345712443139885435713, 1697922281010727896157771357754404141175558213279694827177, -2563354141316214192238665622419043103752271231436289784901, 12649241745548345808537400340160437960898762954765016380, 1085184909547168471531481766938297531726492161970041405, 34366760360547429057172776149134017693482276112497409, -54450649960294983039484956176055034561500703172534563, 70042734584158183417529097351747115013251872719830, 5131115875709260652533134675248298364904970303231, 234352093051288938743572737833815172056719641251, -302986508511321439669674587802503186367141204471], 117483531929343218302277602735805088688616751465021298837326306], [[59813021288411912948897987467097013452477235126246569659779055352097777, 20874739070526013858781678492722010063726797432485329122587482426872677, -1788833340674770334855695423033824882161366383887440104651777075189422, 723699210155124331803838419778179623906476017451370425682153952533637, 14763853504239882391609202305475919791796340204654246671952361314765, 1498004973862217590130657711863715142110961160199231425636704905341, -670046067896892627608781100323945191885807889313811399015888474772, 95470282133310512911090756921206568306614574158577003786166005244, 353982276820688644487624094986061561524266665149925308556838191, 40362756458759077647802773088090850443399805841334952915674885, -15897605816423371917303105657401014127924050472319259526557726, 1986166979073163993050984826604993496710382630656048956690729, 2579783809417210404283429353475831413647259672758041024019, 313403764746111742094923958232676212234757776764674877583, -97269666477652210536001801472082476153568733754761425880, 11246694073490647659112996655592505502935670293337579876], 1962205368426145187699126732066909894878818126915478597350369307086066], [[2545345314466944040266593194164495238139780935940429401231817121003715591562241, -630379962395782463040004840706751391953273846101420220045998945860052518157679, -116285984613234429553557271859584816945868394425885339968765130519311841083671, 34109054355330272404020691294703197930913460972251279871907581000528015727380, 1636290567304197043368937397839291152605447835055922621561304951444400691237, -41982446997932307591060993559832632060724261038131418778622658681793480953, -25310419923259541446539873131468514431512700986276406609308114408659547173, 4532000309345864982955078809530052556393645862940766069195668960337154089, 50363864823760485627151889099462085437172638836193108892920206478099709, -1325210657894266208126433050142368048952120020400169297644632150279581, -549250979857177858553899480944065700596121602496027676768377285987491, 94365103983057602276561833434977175484104739576386109199609828426360, 383795765083473880123138214825116938989586836608499020788778864105, -10548739815219718730963093126655047466450463951653152848773778317, -3174083661695778559823728518280205796373280956771869474239091509, 534036198028343754825688034877931413579102163472262343471047325], 92753018042528197696741614516048508077654754398124878806939137415080087971546], [[-2566888597453039565656301974967310202031376460961981130044251514330535, 893979382440437134618921641695605860240279053487435304774004970117954, 57138627223260051956306307217324007237247504327959899500215488037844, -35718831026906103167414494227399673099443058689093076175249944222032, 1469072473704123128704612268836521602334589615017227182085053827058, 274725051524799208369611239260431656140431686250178541213383128727, 4936052118479493774306032657820196078571238817212537392174031003, -8538508488915923444264112642099850846051207707700905413506471235, 23776205069899912321161145550248923238917706186471922032917817, 6351629530680960005282818423545109055645043720466601598629912, 99796576328994230469833617431009533537771658928774512403254, -186835548016749711898962005535719568748737812353421785702056, 20166593675577646612032365761615125623904033914489238472, 37565116106492108644231561545991045464533362789518013735, 701656945816424777518442584051724983485817706066915743, -1061464709111119038694624004594749679136540634611411209], 129149321521082823325205908895965288395267233364720603636650444422302], [[427565599880270721558584062250679273672302896661371482861344902296729, 382965512648678341806302637440758571590746987989209829183957905400259, -53035299922809052964813848606272947335629123413642070323202452791587, 13497325764026104515494352074040601697776724927581366210477198930290, -92256074142395109979794971510568252035442798945062987388483358631, 105260648857954365598908648189534123627770636661188114679563457587, -900044769302934936585171112514057759556098337658651088319937099, 3182068931151166685367072962806944929704488560897816304861631306, -957850577655015800082067328570544053421454923017779129175287, 2411892159469901706953001163709391540435220406095521189487235, -10997955697619879970086756718523052579545884060687194556261, 69531344785202860308640208201327336059635808330690160819496, 15790995920620399357870016507602216648347966731580684801, 14271831771741231905049032711545561830923896094845757119, -154401621903525609366119811613992005903200027538407549, 394751133711279321026522563454993344800781567679742668], 45632682986654539248816900745742090578577165742220432496520216443862], [[-17004406236627988807964682332208227927037490486515979429585152960038276876115840, -14787306918869789946047500704619382090620934530470545779811200092545130441718551, -527626743111194843699643123826068215221710631036115211946833106357477210634397, -481740415925375843647089191456721139128960058138470762093488676675369462184782, 4045011229444864189544281753103647605292087444977761488586193939437960732130, -5991489022655946584037992801897798988944297829549610194359960624447485900455, -514824621206150930425068502433251185227028778446647959988319083918679430845, -141367559074536223862972158821705511262172906784597078076447624782416531836, 40962811173457597264119310194597941155420801313688722484559526392398626, -131752564648403830100851486111481434187500779573199116889475941104087187, -12282348904146949257916968993073197212085750755291207814772461955878097, -3114824315308766663879901697579264854634706901020939545003934130143360, -699943211707791034428484823070126331232645869516020811299243219584, -724950163693665435368291600001080789563934452191066689412950564011, -70363915343583516667093650514921706815244309009364139596803719517, -17607837819654973111368278694242923666994356507248903114436140650], 1669554324765507558541349061288873145397785579166247818524904473471441583487828], [[545510750201533212224020331699358043192226774915479932161609994, 372556917904017452117824038731380275765275423985406091883851511, 24274894930717053440267675249736343438180151079486265923723063, -14378667354561452567823496654854687180964238111043042900709161, 854354964305385532204633630661645407575360718286363481623820, 140543019556522020697689118661197521001067043671234894040645, 2036428245514088009921729778556817978909559613653985455909, -3818075960513908341314224802171984790973568410927122502269, 21525411673572937253213372770400659118506505673854305974, 3088994379999762381386240971778540626751170237655005081, 41120395679314598510469143602927839518561108855784157, -83601874111830071372485597804970604772824807281947955, 112705740237726295708689719538387309775038909969190, 17165994626898373332226073511204572744043379170179, 293659882681440295942764897945439824097196250463, -472535026606153412386515423785003893324781128855], 39161177309781072767425867578601696229538917155007099612442102], [[-25308333150651215465526602745617606824295035920642617385680510144482608, -20701641954355999533556184990861244719954129908781434682496036124218603, -11892836188583955981411705255854612569619035021952735235802460134254267, -554757175208896026028260984452821473517253793807824336527737110918352, 7157863179279569548584094457498701597110558116076204350603942567738, -14200101616588122171499314801209743172690166141585845522015381167559, -2903080330473570621428189782986585714933953272955154726740650130041, -252083283275163544444735410603634483784434764518585976448082462942, 68753060723234469395299157299414204002545892076624778248047750, -325962782544088398990060615794112138036681808533612278642874171, -61572336066741785666659811303918007489063107449475715681079145, -5704875586991450562656497622151301995012685999105910363202650, -1276031192063673225756271707406128113468273226130650282484, -1837820569441418983806495185064619716649939152374758775439, -333902461709946606393168563724783147999584317417413377323, -32573805876379704307735709453382474885180391498599299276], 1962205368426145187699126732066909894878818126915478597350369307086066], [[59821074490935738844324024010886721391546328223040383408481327071184781, 8079139562329397874903698867078581015707625013560570816591276903188147, 532675952329053208334073127340814190580693189989805741088271963640916, -305047669760289689774793142194245615786044969472045956204626611043846, 21187854874007706228526186005986447787677280920526011127984717654214, 3388969426589642446209717151406094004977864674824387198048620906148, 43822238436550999219590548738803257410109517709204609112045543205, -85927634941946838123313771112775903411432725042520027548043279453, 338324837711720124924551987878427251773980238205460680416599595, 76956458772858926486775725749012287082931203160272593054799633, 884464088293232081781519500152370076443104428545450406070720, -1895871847794420830630750078290254471710080023802058381459180, 727017603598832463899608703521821835691971565929621988778, 442881429345515938705425006849125174868902134041356139512, 6388071824187940827858426561951142032586341315191767511, -10775906150194483103584879882125917573705399923121452301], 427186217338966261767988775578962107768960848821768150490459162319922]]

hecke_ring_character_values = [[127, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [1093, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [449, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [577, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, -3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0], [0, 1, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0], [3, 0, 1, 0, 1, 0, 0, -1, 0, 0, 0, 0, 0, 1, 0, 0], [0, 0, 0, 0, -1, 0, 0, 0, -1, 0, 0, -1, 0, 0, 0, 0], [0, 7, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, -1, 0, 0, 0], [0, 19, 0, -2, 0, -2, 2, 0, 0, 0, 0, 0, 1, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -3, 0, 0, -1, 0], [0, 0, 0, -2, 0, 2, 0, 0, 0, 0, -3, 0, 0, 0, 0, -1], [0, 0, 3, 0, -1, 0, 0, 0, 2, 0, 0, -1, 0, 0, 1, 0], [0, 0, 6, 0, -5, 0, 0, 0, 1, 0, 0, 1, 0, 0, 2, 0], [0, 0, 0, 6, 0, -5, 0, 0, 0, -1, 4, 0, 0, 0, 0, 0], [0, 0, 0, -6, 0, 4, 0, 0, 0, 2, 4, 0, 0, 0, 0, -2], [0, 0, 6, 0, -10, 0, 0, 0, -4, 0, 0, 3, 0, 0, -1, 0], [0, -106, 0, 14, 0, 14, 12, 0, 0, 0, 0, 0, 2, 0, 0, 0], [17, 0, -11, 0, -11, 0, 0, 27, 0, 0, 0, 0, 0, 3, 0, 0], [0, 0, 0, 12, 0, -5, 0, 0, 0, -7, 4, 0, 0, 0, 0, 2], [0, 41, 0, -4, 0, -4, 22, 0, 0, 0, 0, 0, -13, 0, 0, 0], [0, 0, 10, 0, -6, 0, 0, 0, 4, 0, 0, -14, 0, 0, 0, 0], [0, 86, 0, -19, 0, -19, -6, 0, 0, 0, 0, 0, 12, 0, 0, 0], [0, 190, 0, 4, 0, 4, -12, 0, 0, 0, 0, 0, 10, 0, 0, 0], [0, 0, 18, 0, -21, 0, 0, 0, -3, 0, 0, 21, 0, 0, -2, 0], [0, 0, -10, 0, 4, 0, 0, 0, -6, 0, 0, -12, 0, 0, -6, 0], [-176, 0, -32, 0, -32, 0, 0, 9, 0, 0, 0, 0, 0, -16, 0, 0], [0, 0, 0, 6, 0, 4, 0, 0, 0, -10, 19, 0, 0, 0, 0, 5], [0, 0, 0, 36, 0, -38, 0, 0, 0, 2, -13, 0, 0, 0, 0, -2], [0, 0, 24, 0, -30, 0, 0, 0, -6, 0, 0, -30, 0, 0, 2, 0], [82, 0, 4, 0, 4, 0, 0, -98, 0, 0, 0, 0, 0, -4, 0, 0], [0, -86, 0, 27, 0, 27, 114, 0, 0, 0, 0, 0, -12, 0, 0, 0], [0, -84, 0, 30, 0, 30, 62, 0, 0, 0, 0, 0, 0, 0, 0, 0], [560, 0, -40, 0, -40, 0, 0, 74, 0, 0, 0, 0, 0, -14, 0, 0], [0, 486, 0, 64, 0, 64, -38, 0, 0, 0, 0, 0, -22, 0, 0, 0], [0, 0, 60, 0, -48, 0, 0, 0, 12, 0, 0, 19, 0, 0, -1, 0], [0, -950, 0, 29, 0, 29, -140, 0, 0, 0, 0, 0, -4, 0, 0, 0], [-399, 0, -43, 0, -43, 0, 0, 79, 0, 0, 0, 0, 0, 35, 0, 0], [0, 0, 0, 48, 0, -47, 0, 0, 0, -1, 52, 0, 0, 0, 0, 6], [0, 0, 0, -6, 0, 14, 0, 0, 0, -8, 26, 0, 0, 0, 0, 2], [102, 0, -66, 0, -66, 0, 0, 1, 0, 0, 0, 0, 0, 18, 0, 0], [0, 0, 0, 48, 0, -60, 0, 0, 0, 12, -7, 0, 0, 0, 0, -2], [1233, 0, -109, 0, -109, 0, 0, 61, 0, 0, 0, 0, 0, -13, 0, 0], [0, 371, 0, 2, 0, 2, 106, 0, 0, 0, 0, 0, 29, 0, 0, 0], [765, 0, 96, 0, 96, 0, 0, 209, 0, 0, 0, 0, 0, 13, 0, 0], [0, 0, 78, 0, -82, 0, 0, 0, -4, 0, 0, -27, 0, 0, -5, 0], [0, 0, 0, 53, 0, -43, 0, 0, 0, -10, -20, 0, 0, 0, 0, 0], [0, 0, 0, 66, 0, -65, 0, 0, 0, -1, -20, 0, 0, 0, 0, -8], [0, 0, 0, 51, 0, -85, 0, 0, 0, 34, -52, 0, 0, 0, 0, -4], [0, -814, 0, 86, 0, 86, -138, 0, 0, 0, 0, 0, -10, 0, 0, 0], [-1073, 0, -69, 0, -69, 0, 0, -193, 0, 0, 0, 0, 0, -35, 0, 0], [-1008, 0, -36, 0, -36, 0, 0, 12, 0, 0, 0, 0, 0, 66, 0, 0], [0, -675, 0, -90, 0, -90, 294, 0, 0, 0, 0, 0, 51, 0, 0, 0], [0, 0, -108, 0, 104, 0, 0, 0, -4, 0, 0, 20, 0, 0, 6, 0], [0, 644, 0, 50, 0, 50, -84, 0, 0, 0, 0, 0, 80, 0, 0, 0], [0, 0, 42, 0, -65, 0, 0, 0, -23, 0, 0, -71, 0, 0, -6, 0], [0, -1853, 0, -68, 0, -68, -190, 0, 0, 0, 0, 0, 13, 0, 0, 0], [-1150, 0, -118, 0, -118, 0, 0, -69, 0, 0, 0, 0, 0, -98, 0, 0], [0, 0, 0, 62, 0, -24, 0, 0, 0, -38, 89, 0, 0, 0, 0, -21], [0, 0, 99, 0, -61, 0, 0, 0, 38, 0, 0, 65, 0, 0, -17, 0], [1510, 0, -104, 0, -104, 0, 0, -446, 0, 0, 0, 0, 0, 20, 0, 0], [0, -495, 0, 68, 0, 68, 323, 0, 0, 0, 0, 0, 49, 0, 0, 0], [1518, 0, 54, 0, 54, 0, 0, 25, 0, 0, 0, 0, 0, 90, 0, 0], [0, 1573, 0, 32, 0, 32, 423, 0, 0, 0, 0, 0, -27, 0, 0, 0], [0, 0, 0, -156, 0, 146, 0, 0, 0, 10, 80, 0, 0, 0, 0, -2], [0, 0, 38, 0, 24, 0, 0, 0, 62, 0, 0, -16, 0, 0, -16, 0], [0, 0, -12, 0, -48, 0, 0, 0, -60, 0, 0, 19, 0, 0, -1, 0], [0, 0, 0, 120, 0, -113, 0, 0, 0, -7, 130, 0, 0, 0, 0, -30], [266, 0, -28, 0, -28, 0, 0, -284, 0, 0, 0, 0, 0, -148, 0, 0], [0, 0, 0, 144, 0, -108, 0, 0, 0, -36, -5, 0, 0, 0, 0, -4], [23, 0, 15, 0, 15, 0, 0, 145, 0, 0, 0, 0, 0, -67, 0, 0], [0, 0, 246, 0, -231, 0, 0, 0, 15, 0, 0, 123, 0, 0, -2, 0], [0, 4435, 0, -176, 0, -176, 86, 0, 0, 0, 0, 0, -119, 0, 0, 0], [0, 0, 0, -11, 0, 25, 0, 0, 0, -14, 152, 0, 0, 0, 0, 32], [0, 0, -6, 0, 96, 0, 0, 0, 90, 0, 0, -102, 0, 0, -34, 0], [0, 0, 0, 54, 0, -61, 0, 0, 0, 7, -232, 0, 0, 0, 0, 12], [0, 0, 0, -234, 0, 220, 0, 0, 0, 14, 46, 0, 0, 0, 0, 44], [0, 0, -102, 0, 82, 0, 0, 0, -20, 0, 0, -141, 0, 0, 29, 0], [-3543, 0, -17, 0, -17, 0, 0, -289, 0, 0, 0, 0, 0, 19, 0, 0], [-2252, 0, -224, 0, -224, 0, 0, -470, 0, 0, 0, 0, 0, -46, 0, 0], [0, 0, 14, 0, 0, 0, 0, 0, 14, 0, 0, 176, 0, 0, -26, 0], [0, 1880, 0, -364, 0, -364, -118, 0, 0, 0, 0, 0, 92, 0, 0, 0], [0, 0, -99, 0, 73, 0, 0, 0, -26, 0, 0, 19, 0, 0, -75, 0], [0, -4217, 0, -314, 0, -314, -382, 0, 0, 0, 0, 0, -35, 0, 0, 0], [0, 0, -92, 0, 104, 0, 0, 0, 12, 0, 0, -24, 0, 0, -20, 0], [0, 0, 0, 7, 0, 13, 0, 0, 0, -20, -340, 0, 0, 0, 0, 20], [0, 0, 0, 12, 0, -82, 0, 0, 0, 70, -55, 0, 0, 0, 0, 52], [2262, 0, -456, 0, -456, 0, 0, 234, 0, 0, 0, 0, 0, -132, 0, 0], [-3248, 0, 46, 0, 46, 0, 0, 314, 0, 0, 0, 0, 0, 70, 0, 0], [1464, 0, 192, 0, 192, 0, 0, -269, 0, 0, 0, 0, 0, 144, 0, 0], [0, 1292, 0, 41, 0, 41, 20, 0, 0, 0, 0, 0, -86, 0, 0, 0], [0, -6632, 0, -278, 0, -278, 568, 0, 0, 0, 0, 0, 4, 0, 0, 0], [0, 0, 0, -180, 0, 202, 0, 0, 0, -22, 154, 0, 0, 0, 0, -4], [0, -5272, 0, 9, 0, 9, 90, 0, 0, 0, 0, 0, 162, 0, 0, 0], [0, 0, 0, 120, 0, -62, 0, 0, 0, -58, 185, 0, 0, 0, 0, -42], [0, 0, 0, -552, 0, 497, 0, 0, 0, 55, -34, 0, 0, 0, 0, 34], [0, 0, 0, -342, 0, 244, 0, 0, 0, 98, 136, 0, 0, 0, 0, -42], [-8420, 0, 304, 0, 304, 0, 0, 483, 0, 0, 0, 0, 0, -148, 0, 0], [0, 0, 60, 0, -125, 0, 0, 0, -65, 0, 0, -5, 0, 0, 48, 0], [0, -8482, 0, 52, 0, 52, -174, 0, 0, 0, 0, 0, -78, 0, 0, 0], [0, 0, -369, 0, 331, 0, 0, 0, -38, 0, 0, -227, 0, 0, 39, 0], [0, 0, 0, -564, 0, 521, 0, 0, 0, 43, -100, 0, 0, 0, 0, 34], [0, 0, -120, 0, 80, 0, 0, 0, -40, 0, 0, 177, 0, 0, -63, 0], [0, 1046, 0, -832, 0, -832, -676, 0, 0, 0, 0, 0, 50, 0, 0, 0], [-3500, 0, -164, 0, -164, 0, 0, 460, 0, 0, 0, 0, 0, -214, 0, 0], [0, 0, 0, 66, 0, 27, 0, 0, 0, -93, 18, 0, 0, 0, 0, 56], [0, 0, -138, 0, 160, 0, 0, 0, 22, 0, 0, -248, 0, 0, 16, 0], [0, 5882, 0, 128, 0, 128, -514, 0, 0, 0, 0, 0, -130, 0, 0, 0], [0, 0, 528, 0, -427, 0, 0, 0, 101, 0, 0, 101, 0, 0, -4, 0], [0, -1403, 0, -164, 0, -164, 602, 0, 0, 0, 0, 0, -65, 0, 0, 0], [0, 0, -416, 0, 474, 0, 0, 0, 58, 0, 0, -110, 0, 0, -38, 0], [0, 0, 0, 399, 0, -545, 0, 0, 0, 146, 292, 0, 0, 0, 0, 16], [0, 0, -324, 0, 318, 0, 0, 0, -6, 0, 0, 84, 0, 0, 0, 0], [5708, 0, 104, 0, 104, 0, 0, 362, 0, 0, 0, 0, 0, 274, 0, 0], [0, -3302, 0, 20, 0, 20, 1278, 0, 0, 0, 0, 0, 30, 0, 0, 0], [0, -2842, 0, 353, 0, 353, -418, 0, 0, 0, 0, 0, -44, 0, 0, 0], [1470, 0, -360, 0, -360, 0, 0, 444, 0, 0, 0, 0, 0, 0, 0, 0], [0, 10113, 0, -640, 0, -640, 107, 0, 0, 0, 0, 0, -143, 0, 0, 0], [0, 0, 0, -336, 0, 352, 0, 0, 0, -16, -326, 0, 0, 0, 0, 46], [0, 0, -210, 0, 314, 0, 0, 0, 104, 0, 0, -173, 0, 0, -53, 0], [0, 0, 0, -624, 0, 614, 0, 0, 0, 10, 49, 0, 0, 0, 0, 58], [-3497, 0, 227, 0, 227, 0, 0, 1761, 0, 0, 0, 0, 0, -51, 0, 0], [545, 0, 216, 0, 216, 0, 0, 933, 0, 0, 0, 0, 0, 69, 0, 0], [-16338, 0, 6, 0, 6, 0, 0, 1001, 0, 0, 0, 0, 0, 90, 0, 0], [0, 0, 0, -12, 0, -230, 0, 0, 0, 242, 133, 0, 0, 0, 0, -56], [0, -16290, 0, -476, 0, -476, -1514, 0, 0, 0, 0, 0, -94, 0, 0, 0], [0, 0, -300, 0, 332, 0, 0, 0, 32, 0, 0, -137, 0, 0, -149, 0], [0, 0, -174, 0, 4, 0, 0, 0, -170, 0, 0, 40, 0, 0, 12, 0], [0, 0, 0, -432, 0, 594, 0, 0, 0, -162, 402, 0, 0, 0, 0, -52], [0, 0, 0, 178, 0, 112, 0, 0, 0, -290, 269, 0, 0, 0, 0, 23], [-16915, 0, 597, 0, 597, 0, 0, -1139, 0, 0, 0, 0, 0, 383, 0, 0], [0, 0, 0, -528, 0, 451, 0, 0, 0, 77, 64, 0, 0, 0, 0, 42], [0, -12135, 0, -426, 0, -426, -1986, 0, 0, 0, 0, 0, -57, 0, 0, 0], [0, -3182, 0, 297, 0, 297, -408, 0, 0, 0, 0, 0, -84, 0, 0, 0], [0, 0, 54, 0, 128, 0, 0, 0, 182, 0, 0, -160, 0, 0, 128, 0], [0, 0, -180, 0, 213, 0, 0, 0, 33, 0, 0, 429, 0, 0, -144, 0], [0, 0, -116, 0, 206, 0, 0, 0, 90, 0, 0, 498, 0, 0, 6, 0], [-4256, 0, 280, 0, 280, 0, 0, -1789, 0, 0, 0, 0, 0, 152, 0, 0], [0, -7188, 0, -152, 0, -152, 1720, 0, 0, 0, 0, 0, -136, 0, 0, 0], [13706, 0, -130, 0, -130, 0, 0, 175, 0, 0, 0, 0, 0, -170, 0, 0], [-4368, 0, 132, 0, 132, 0, 0, -2460, 0, 0, 0, 0, 0, 174, 0, 0], [0, 18414, 0, 272, 0, 272, 590, 0, 0, 0, 0, 0, 130, 0, 0, 0], [0, 0, -78, 0, -182, 0, 0, 0, -260, 0, 0, -389, 0, 0, 47, 0], [0, 2140, 0, 181, 0, 181, 540, 0, 0, 0, 0, 0, -558, 0, 0, 0], [0, 0, 0, 312, 0, -500, 0, 0, 0, 188, -605, 0, 0, 0, 0, 10], [-11193, 0, 167, 0, 167, 0, 0, 1555, 0, 0, 0, 0, 0, -187, 0, 0], [0, 0, 0, -486, 0, 382, 0, 0, 0, 104, -152, 0, 0, 0, 0, 140], [25181, 0, 505, 0, 505, 0, 0, 519, 0, 0, 0, 0, 0, 183, 0, 0], [0, 0, 192, 0, 69, 0, 0, 0, 261, 0, 0, -171, 0, 0, 4, 0], [0, -24079, 0, 276, 0, 276, -1369, 0, 0, 0, 0, 0, 49, 0, 0, 0], [0, -12437, 0, 58, 0, 58, 602, 0, 0, 0, 0, 0, -59, 0, 0, 0], [0, 0, 564, 0, -502, 0, 0, 0, 62, 0, 0, 632, 0, 0, 0, 0], [0, 0, 648, 0, -637, 0, 0, 0, 11, 0, 0, -757, 0, 0, -92, 0], [0, 0, 0, -348, 0, 503, 0, 0, 0, -155, 350, 0, 0, 0, 0, -142], [0, 0, 0, -750, 0, 786, 0, 0, 0, -36, -378, 0, 0, 0, 0, 142], [0, 0, 0, 642, 0, -693, 0, 0, 0, 51, -648, 0, 0, 0, 0, 4], [0, 1517, 0, -748, 0, -748, -962, 0, 0, 0, 0, 0, 203, 0, 0, 0], [0, 9048, 0, -633, 0, -633, -982, 0, 0, 0, 0, 0, -146, 0, 0, 0], [0, 0, 966, 0, -1019, 0, 0, 0, -53, 0, 0, 223, 0, 0, 98, 0], [0, 0, 694, 0, -574, 0, 0, 0, 120, 0, 0, 42, 0, 0, 90, 0], [-5578, 0, -598, 0, -598, 0, 0, -845, 0, 0, 0, 0, 0, 202, 0, 0], [0, 0, 0, 0, 0, 12, 0, 0, 0, -12, 581, 0, 0, 0, 0, 194], [6836, 0, -172, 0, -172, 0, 0, 698, 0, 0, 0, 0, 0, -530, 0, 0], [0, 1366, 0, 167, 0, 167, -1034, 0, 0, 0, 0, 0, -136, 0, 0, 0], [0, -30766, 0, 710, 0, 710, 66, 0, 0, 0, 0, 0, 278, 0, 0, 0], [-8526, 0, -1272, 0, -1272, 0, 0, 1122, 0, 0, 0, 0, 0, -96, 0, 0], [0, 0, 0, -30, 0, 418, 0, 0, 0, -388, 358, 0, 0, 0, 0, -90], [0, -3318, 0, 603, 0, 603, 1444, 0, 0, 0, 0, 0, 80, 0, 0, 0], [-9571, 0, -1019, 0, -1019, 0, 0, 1299, 0, 0, 0, 0, 0, -57, 0, 0], [-9057, 0, -522, 0, -522, 0, 0, 1975, 0, 0, 0, 0, 0, -109, 0, 0], [-30832, 0, -28, 0, -28, 0, 0, -473, 0, 0, 0, 0, 0, 184, 0, 0], [0, 0, 0, 1260, 0, -778, 0, 0, 0, -482, 343, 0, 0, 0, 0, 46], [21015, 0, -487, 0, -487, 0, 0, -83, 0, 0, 0, 0, 0, -283, 0, 0], [0, 1591, 0, 766, 0, 766, 686, 0, 0, 0, 0, 0, -359, 0, 0, 0], [-6465, 0, 352, 0, 352, 0, 0, -2597, 0, 0, 0, 0, 0, 503, 0, 0], [0, 0, 0, -181, 0, 341, 0, 0, 0, -160, 232, 0, 0, 0, 0, -144], [0, 0, -384, 0, 353, 0, 0, 0, -31, 0, 0, 713, 0, 0, 188, 0], [0, 0, 0, 1098, 0, -1513, 0, 0, 0, 415, 530, 0, 0, 0, 0, 80], [0, 0, 1242, 0, -1270, 0, 0, 0, -28, 0, 0, -455, 0, 0, -19, 0], [0, 0, 0, -98, 0, 362, 0, 0, 0, -264, 285, 0, 0, 0, 0, -57], [-30861, 0, -1493, 0, -1493, 0, 0, -1627, 0, 0, 0, 0, 0, -527, 0, 0], [0, -17826, 0, 31, 0, 31, 986, 0, 0, 0, 0, 0, -56, 0, 0, 0], [0, 22476, 0, 654, 0, 654, -2476, 0, 0, 0, 0, 0, -504, 0, 0, 0], [0, 0, 447, 0, -481, 0, 0, 0, -34, 0, 0, -1147, 0, 0, -121, 0], [0, 0, -444, 0, 639, 0, 0, 0, 195, 0, 0, -609, 0, 0, 48, 0], [0, 27365, 0, -370, 0, -370, 358, 0, 0, 0, 0, 0, 11, 0, 0, 0], [-19640, 0, -44, 0, -44, 0, 0, 1071, 0, 0, 0, 0, 0, 416, 0, 0], [0, 0, 240, 0, -478, 0, 0, 0, -238, 0, 0, 26, 0, 0, -226, 0], [0, -2372, 0, 288, 0, 288, 2824, 0, 0, 0, 0, 0, -616, 0, 0, 0], [11921, 0, -504, 0, -504, 0, 0, 1329, 0, 0, 0, 0, 0, -75, 0, 0], [0, 0, 0, 936, 0, -1314, 0, 0, 0, 378, 528, 0, 0, 0, 0, 98], [0, 0, -30, 0, 144, 0, 0, 0, 114, 0, 0, -348, 0, 0, -194, 0], [0, 0, 0, 984, 0, -480, 0, 0, 0, -504, 575, 0, 0, 0, 0, 150], [0, 0, 0, 678, 0, -557, 0, 0, 0, -121, -908, 0, 0, 0, 0, -192], [-46152, 0, -432, 0, -432, 0, 0, 2609, 0, 0, 0, 0, 0, 360, 0, 0], [0, 0, 0, 432, 0, -310, 0, 0, 0, -122, 875, 0, 0, 0, 0, -146], [0, 0, -1032, 0, 917, 0, 0, 0, -115, 0, 0, 773, 0, 0, -52, 0], [-12629, 0, 1330, 0, 1330, 0, 0, 2111, 0, 0, 0, 0, 0, -449, 0, 0], [0, 0, -99, 0, 605, 0, 0, 0, 506, 0, 0, 1199, 0, 0, -107, 0], [0, 0, 408, 0, -339, 0, 0, 0, 69, 0, 0, 1425, 0, 0, -148, 0], [0, 0, 0, 636, 0, -578, 0, 0, 0, -58, 472, 0, 0, 0, 0, 10], [0, 0, 918, 0, -1162, 0, 0, 0, -244, 0, 0, 169, 0, 0, -45, 0], [0, 0, 0, 205, 0, -513, 0, 0, 0, 308, -224, 0, 0, 0, 0, 200], [-40251, 0, 313, 0, 313, 0, 0, -1099, 0, 0, 0, 0, 0, 295, 0, 0], [0, 0, -250, 0, 674, 0, 0, 0, 424, 0, 0, -302, 0, 0, -16, 0], [0, 20620, 0, 1138, 0, 1138, 616, 0, 0, 0, 0, 0, -8, 0, 0, 0], [4058, 0, 98, 0, 98, 0, 0, -813, 0, 0, 0, 0, 0, -362, 0, 0], [0, 0, 0, -687, 0, 1011, 0, 0, 0, -324, -1092, 0, 0, 0, 0, 128], [0, 0, 0, -564, 0, 94, 0, 0, 0, 470, -183, 0, 0, 0, 0, 240], [22616, 0, 524, 0, 524, 0, 0, -2062, 0, 0, 0, 0, 0, -794, 0, 0], [0, -4195, 0, 300, 0, 300, 1907, 0, 0, 0, 0, 0, 781, 0, 0, 0], [4168, 0, -26, 0, -26, 0, 0, -2674, 0, 0, 0, 0, 0, -146, 0, 0], [39042, 0, -450, 0, -450, 0, 0, -329, 0, 0, 0, 0, 0, -546, 0, 0], [0, 1190, 0, 49, 0, 49, 1304, 0, 0, 0, 0, 0, -8, 0, 0, 0], [0, -50000, 0, 436, 0, 436, -576, 0, 0, 0, 0, 0, -164, 0, 0, 0], [0, 0, 0, 708, 0, -826, 0, 0, 0, 118, 770, 0, 0, 0, 0, 48], [0, 0, 208, 0, 72, 0, 0, 0, 280, 0, 0, 772, 0, 0, -180, 0], [0, 4202, 0, -817, 0, -817, -3256, 0, 0, 0, 0, 0, 16, 0, 0, 0], [0, 0, -390, 0, 973, 0, 0, 0, 583, 0, 0, 931, 0, 0, 138, 0], [0, 3339, 0, -216, 0, -216, -1098, 0, 0, 0, 0, 0, 837, 0, 0, 0], [0, 0, -1290, 0, 842, 0, 0, 0, -448, 0, 0, -7, 0, 0, 183, 0], [0, 0, 1230, 0, -1552, 0, 0, 0, -322, 0, 0, 428, 0, 0, 156, 0], [0, 0, 0, -654, 0, 386, 0, 0, 0, 268, -427, 0, 0, 0, 0, 151], [18106, 0, -32, 0, -32, 0, 0, -2402, 0, 0, 0, 0, 0, -712, 0, 0], [0, -32070, 0, -1691, 0, -1691, -2092, 0, 0, 0, 0, 0, 532, 0, 0, 0], [0, 27218, 0, -268, 0, -268, -1300, 0, 0, 0, 0, 0, 638, 0, 0, 0], [0, 0, -417, 0, 259, 0, 0, 0, -158, 0, 0, -1361, 0, 0, 93, 0], [0, 0, -1728, 0, 1137, 0, 0, 0, -591, 0, 0, -567, 0, 0, 196, 0], [0, 35907, 0, 1770, 0, 1770, -1506, 0, 0, 0, 0, 0, -423, 0, 0, 0], [0, 0, 0, -402, 0, 802, 0, 0, 0, -400, 505, 0, 0, 0, 0, -161], [0, 0, 0, 708, 0, 102, 0, 0, 0, -810, 747, 0, 0, 0, 0, 42], [0, 0, 678, 0, -164, 0, 0, 0, 514, 0, 0, -56, 0, 0, 104, 0], [0, -15545, 0, 912, 0, 912, 373, 0, 0, 0, 0, 0, -1, 0, 0, 0], [0, 36088, 0, 1003, 0, 1003, 1450, 0, 0, 0, 0, 0, -442, 0, 0, 0], [-45412, 0, 2228, 0, 2228, 0, 0, -1276, 0, 0, 0, 0, 0, -122, 0, 0], [0, 24981, 0, -1388, 0, -1388, -2429, 0, 0, 0, 0, 0, 965, 0, 0, 0], [0, 0, 0, 138, 0, 422, 0, 0, 0, -560, -616, 0, 0, 0, 0, 48], [0, 0, -756, 0, 1262, 0, 0, 0, 506, 0, 0, 134, 0, 0, 240, 0], [0, 0, -1044, 0, 1216, 0, 0, 0, 172, 0, 0, 1837, 0, 0, 183, 0], [0, 0, 0, -480, 0, -290, 0, 0, 0, 770, -51, 0, 0, 0, 0, -180], [0, 0, 0, 1062, 0, -1024, 0, 0, 0, -38, -1216, 0, 0, 0, 0, -142], [0, 0, 0, -792, 0, 314, 0, 0, 0, 478, -373, 0, 0, 0, 0, 232], [0, -54348, 0, 460, 0, 460, 2296, 0, 0, 0, 0, 0, -928, 0, 0, 0], [0, 0, 0, 289, 0, -285, 0, 0, 0, -4, -896, 0, 0, 0, 0, -192], [0, 0, 363, 0, -917, 0, 0, 0, -554, 0, 0, -269, 0, 0, -263, 0], [0, 0, 354, 0, -163, 0, 0, 0, 191, 0, 0, -1045, 0, 0, -58, 0], [0, 0, 0, 1158, 0, -1826, 0, 0, 0, 668, 220, 0, 0, 0, 0, 12], [0, 0, 0, -1930, 0, 1428, 0, 0, 0, 502, 455, 0, 0, 0, 0, -43], [0, -10134, 0, 732, 0, 732, 634, 0, 0, 0, 0, 0, 366, 0, 0, 0], [0, 0, 0, -858, 0, 199, 0, 0, 0, 659, 118, 0, 0, 0, 0, -272], [0, -17733, 0, 144, 0, 144, 4242, 0, 0, 0, 0, 0, 189, 0, 0, 0], [0, 0, -1404, 0, 1870, 0, 0, 0, 466, 0, 0, 610, 0, 0, -26, 0], [0, 0, 60, 0, 267, 0, 0, 0, 327, 0, 0, 1611, 0, 0, -36, 0], [0, 42561, 0, -1482, 0, -1482, -3690, 0, 0, 0, 0, 0, 1587, 0, 0, 0], [0, 0, 1982, 0, -2248, 0, 0, 0, -266, 0, 0, -296, 0, 0, 14, 0], [21960, 0, -372, 0, -372, 0, 0, 3539, 0, 0, 0, 0, 0, -48, 0, 0], [0, 0, 0, 408, 0, 16, 0, 0, 0, -424, -9, 0, 0, 0, 0, -378], [0, 0, -825, 0, 807, 0, 0, 0, -18, 0, 0, 393, 0, 0, 171, 0], [0, -10043, 0, -1104, 0, -1104, -2117, 0, 0, 0, 0, 0, -907, 0, 0, 0], [53986, 0, 958, 0, 958, 0, 0, -1485, 0, 0, 0, 0, 0, 686, 0, 0], [0, 0, 3740, 0, -3424, 0, 0, 0, 316, 0, 0, 400, 0, 0, 100, 0], [0, 364, 0, -873, 0, -873, -948, 0, 0, 0, 0, 0, -786, 0, 0, 0], [0, 0, 0, 144, 0, -246, 0, 0, 0, 102, 331, 0, 0, 0, 0, -90], [-50073, 0, 1477, 0, 1477, 0, 0, -2557, 0, 0, 0, 0, 0, 829, 0, 0], [89, 0, 2847, 0, 2847, 0, 0, -989, 0, 0, 0, 0, 0, 83, 0, 0], [0, 0, 450, 0, -605, 0, 0, 0, -155, 0, 0, -2339, 0, 0, 14, 0], [0, -31730, 0, 588, 0, 588, -3914, 0, 0, 0, 0, 0, -1102, 0, 0, 0], [0, 0, 756, 0, -256, 0, 0, 0, 500, 0, 0, -1009, 0, 0, -311, 0], [0, 0, -2394, 0, 2675, 0, 0, 0, 281, 0, 0, -823, 0, 0, 98, 0], [0, 0, 0, -2220, 0, 2499, 0, 0, 0, -279, 132, 0, 0, 0, 0, 58], [0, 0, -1842, 0, 1902, 0, 0, 0, 60, 0, 0, 1197, 0, 0, -311, 0], [-57305, 0, 141, 0, 141, 0, 0, -1339, 0, 0, 0, 0, 0, 1045, 0, 0], [0, 0, 0, -660, 0, 421, 0, 0, 0, 239, -794, 0, 0, 0, 0, 414], [0, 0, 1192, 0, -1110, 0, 0, 0, 82, 0, 0, -1514, 0, 0, 512, 0], [0, -38576, 0, 381, 0, 381, 3666, 0, 0, 0, 0, 0, 450, 0, 0, 0], [0, 0, -698, 0, 600, 0, 0, 0, -98, 0, 0, -848, 0, 0, 74, 0], [0, 0, 0, -2710, 0, 2562, 0, 0, 0, 148, 1565, 0, 0, 0, 0, -81], [0, 0, 0, -1860, 0, 1794, 0, 0, 0, 66, -311, 0, 0, 0, 0, -8], [0, 0, -2205, 0, 1875, 0, 0, 0, -330, 0, 0, -681, 0, 0, -19, 0], [-2011, 0, -1264, 0, -1264, 0, 0, -1775, 0, 0, 0, 0, 0, 221, 0, 0], [0, -68994, 0, 948, 0, 948, -326, 0, 0, 0, 0, 0, 306, 0, 0, 0], [0, 0, 0, 1392, 0, -1396, 0, 0, 0, 4, -982, 0, 0, 0, 0, 50], [0, -6296, 0, -419, 0, -419, -3728, 0, 0, 0, 0, 0, 1166, 0, 0, 0], [0, 0, 0, 696, 0, -664, 0, 0, 0, -32, 326, 0, 0, 0, 0, 178], [64911, 0, 305, 0, 305, 0, 0, 337, 0, 0, 0, 0, 0, -547, 0, 0], [0, -34666, 0, -3416, 0, -3416, 4806, 0, 0, 0, 0, 0, 1386, 0, 0, 0], [0, -54103, 0, 1376, 0, 1376, -2558, 0, 0, 0, 0, 0, -25, 0, 0, 0], [31022, 0, -1788, 0, -1788, 0, 0, 2628, 0, 0, 0, 0, 0, 300, 0, 0], [0, 0, -1458, 0, 1278, 0, 0, 0, -180, 0, 0, 607, 0, 0, -179, 0], [0, 0, 0, -606, 0, 892, 0, 0, 0, -286, -371, 0, 0, 0, 0, 359], [0, 0, -222, 0, -241, 0, 0, 0, -463, 0, 0, 2225, 0, 0, 182, 0], [0, 0, 1470, 0, -2202, 0, 0, 0, -732, 0, 0, 945, 0, 0, -5, 0], [0, -10696, 0, -22, 0, -22, 2646, 0, 0, 0, 0, 0, -484, 0, 0, 0], [7072, 0, 2932, 0, 2932, 0, 0, -1838, 0, 0, 0, 0, 0, -322, 0, 0], [0, 33438, 0, -1794, 0, -1794, 2276, 0, 0, 0, 0, 0, 666, 0, 0, 0], [0, 0, -738, 0, 488, 0, 0, 0, -250, 0, 0, 3098, 0, 0, 110, 0], [3562, 0, 2806, 0, 2806, 0, 0, -235, 0, 0, 0, 0, 0, 254, 0, 0], [0, 0, 0, 1067, 0, -1345, 0, 0, 0, 278, 2044, 0, 0, 0, 0, -376], [80558, 0, 2414, 0, 2414, 0, 0, -2477, 0, 0, 0, 0, 0, 610, 0, 0], [0, -32466, 0, -2322, 0, -2322, -5386, 0, 0, 0, 0, 0, 930, 0, 0, 0], [0, 8892, 0, 1024, 0, 1024, 2848, 0, 0, 0, 0, 0, 1112, 0, 0, 0], [0, 0, -642, 0, 564, 0, 0, 0, -78, 0, 0, -1668, 0, 0, -500, 0], [0, 0, 1188, 0, -1496, 0, 0, 0, -308, 0, 0, 2507, 0, 0, -19, 0], [0, -46610, 0, -1727, 0, -1727, -854, 0, 0, 0, 0, 0, 596, 0, 0, 0]]
